@@ -92,12 +92,16 @@ def run(raw_args=None):
 
     with timed("All"):
         with timed("Find"):
-            if args.pattern == "BUILTINS":
+            if args.pattern == "robotframework":
                 matches = finder.builtins()
                 include = "*"
+            elif args.pattern == "rpaframework":
+                matches = finder.rpaframework()
+                include = "*"
             else:
                 matches = finder.find_all(curdir=(not args.no_curdir))
                 include = args.pattern
+            matches.sort()
 
         with timed("Filter"):
             matches = filter_include(matches, [include])
